# Changelog

Here we provide notes that summarize the most important changes in each released version.

Please consult the changelog to inform yourself about breaking changes and security issues.

## [v0.1.0](https://github.com/Materials-Data-Science-and-Informatics/metador-core/tree/v0.1.0) <small>(2023-08-08)</small> { id="0.1.0" }

* updated dependencies to unpin versions
* removed unused dependencies
* minor tweaks and fixes

## [v0.0.2](https://github.com/Materials-Data-Science-and-Informatics/metador-core/tree/v0.0.2) <small>(2022-12-12)</small> { id="0.0.2" }

* minor tweaks and fixes

## [v0.0.1](https://github.com/Materials-Data-Science-and-Informatics/metador-core/tree/v0.0.1) <small>(2022-10-10)</small> { id="0.0.1" }

* first PyPI release

